@@ -6,7 +6,7 @@
 #	file:   Gato.py
 #	author: Alexander Schliep (alexander@schliep.org)
 #
-#       Copyright (C) 1998-2011, Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
 #       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
 #       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de
@@ -30,8 +30,8 @@
 #
 #
 #
-#       This file is version $Revision: 445 $ 
-#                       from $Date: 2011-08-25 10:43:21 -0400 (Thu, 25 Aug 2011) $
+#       This file is version $Revision: 670 $ 
+#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -185,6 +185,7 @@ class AlgoWin(Frame):
         self.pack()
         self.pack(expand=1,fill=BOTH) # Makes menuBar and toolBar sizeable
         self.makeMenuBar()
+        #a = raw_input()
         self.makeAlgoTextWidget()
         self.makeToolBar()
         self.master.title("Gato %s - Algorithm" % GatoGlobals.gatoVersion)
@@ -474,17 +475,17 @@ class AlgoWin(Frame):
             if self.graph_panes:
                 # We only get here during startup as show/hide is handled by
                 # moving the sash
-                self.secondaryGraphDisplay = GraphDisplayFrame(self.graph_panes)
+                self.secondaryGraphDisplay = GraphDisplayFrame(self.graph_panes, number=2)
             else:
                 self.secondaryGraphDisplay = GraphDisplayToplevel()
             self.BindKeys(self.secondaryGraphDisplay)
             # Provide undo and logging of animations if required
             if self.algorithm.logAnimator == 1:
-                self.secondaryGraphDisplay = AnimationHistory(self.secondaryGraphDisplay)
+                self.secondaryGraphDisplay = AnimationHistory(self.secondaryGraphDisplay, displayNum=2)
             elif self.algorithm.logAnimator == 2:
                 self.secondaryGraphDisplay = AnimationHistory(self.secondaryGraphDisplay,
-                                                          'disp2\t')
-                self.secondaryGraphDisplay.auto_print = 1
+                                                          'disp2\t', displayNum=2)
+                #self.secondaryGraphDisplay.auto_print = 1
         else:
             if self.graph_panes:
                 self.setSash(0.5)
@@ -613,9 +614,7 @@ class AlgoWin(Frame):
             self.tagLines(self.algorithm.GetBreakpointLines(), 'Break')
             
             # Syntax highlighting
-            tokenize.tokenize(StringIO.StringIO(self.algorithm.GetSource()).readline, 
-                              self.tokenEater)
-            
+            tokenize.tokenize(StringIO.StringIO(self.algorithm.GetSource()).readline, self.tokenEater)
             
             if self.algorithm.ReadyToStart():
                 self.buttonStart['state'] = NORMAL 
@@ -661,7 +660,7 @@ class AlgoWin(Frame):
                 self.AboutGraphDialog.Update(
                     self.graphDisplay.About(stripPath(self.algorithm.graphFileName)),
                     "About Graph")
-                
+
     def SaveGatoFile(self,filename=""):
         """
         under Construction...
@@ -842,21 +841,24 @@ class AlgoWin(Frame):
         if file is not "": 
             self.graphDisplay.PrintToPSFile(file)
 
-    def ExportSVG(self):
+    def ExportSVG(self, fileName=None, write_to_png=False):
         """ GUI to control export of SVG file  """
-        fileName = asksaveasfilename(title="Export SVG",
+        if not fileName:
+            fileName = asksaveasfilename(title="Export SVG",
                                  defaultextension=".svg",
                                  filetypes = [("SVG", ".svg")]
                                  )
         if fileName is not "":
             import GatoExport
-            GatoExport.ExportSVG(fileName, self, self.algorithm,
-                                 self.graphDisplay,
-                                 self.secondaryGraphDisplay.animator, #XXX potential bug
-                                 # self.secondaryGraphDisplay is AnimationHistory(sec...)
-                                 showAnimation=False)
 
-    def ExportSVGAnimation(self, fileName=None):
+            if not self.secondaryGraphDisplay or self.algorithm.graphDisplays == None or self.algorithm.graphDisplays == 1:
+                return GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay, 
+                    showAnimation=False, write_to_png=write_to_png)
+            else:
+                return GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay,
+                    self.secondaryGraphDisplay.animator, showAnimation=False, write_to_png=write_to_png)
+
+    def ExportSVGAnimation(self, fileName=None, chapter_number=None, algo_div=None):
         """ GUI to control export of SVG file  """
         if not fileName:
             fileName = asksaveasfilename(title="Export SVG",
@@ -865,27 +867,18 @@ class AlgoWin(Frame):
                                          )
         if fileName is not "":
             import GatoExport
-
             # We never destroy the secondary graph display (and create it from the beginning
             # for the paned viewed. graphDisplays is set from prolog
-            if self.algorithm.graphDisplays == None or self.algorithm.graphDisplays == 1:
-                GatoExport.ExportSVG(fileName,
-                                     self,
-                                     self.algorithm,
-                                     self.graphDisplay,
-                                     None,
-                                     None,
-                                     showAnimation=True)
+            if not self.secondaryGraphDisplay or self.algorithm.graphDisplays == None or self.algorithm.graphDisplays == 1:
+                GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay, None, None, showAnimation=True, 
+                    init_edge_infos=self.algorithm.DB.init_edge_infos, init_vertex_infos=self.algorithm.DB.init_vertex_infos,
+                    init_graph_infos=self.algorithm.DB.init_graph_infos, chapter_number=chapter_number, algo_div=algo_div)
             else:
-                GatoExport.ExportSVG(fileName,
-                                     self,
-                                     self.algorithm,
-                                     self.graphDisplay,
-                                     self.secondaryGraphDisplay.animator, #XXX potential bug
-                                     # self.secondaryGraphDisplay is AnimationHistory(sec...),
-                                     self.secondaryGraphDisplay,
-                                     showAnimation=True)
-            
+                GatoExport.ExportSVG(fileName, self, self.algorithm, self.graphDisplay,
+                    self.secondaryGraphDisplay.animator, self.secondaryGraphDisplay, showAnimation=True,
+                    init_edge_infos=self.algorithm.DB.init_edge_infos, init_vertex_infos=self.algorithm.DB.init_vertex_infos,
+                    init_graph_infos=self.algorithm.DB.init_graph_infos, chapter_number=chapter_number, algo_div=algo_div)
+
     def Quit(self,event=None):
         if self.algorithmIsRunning == 1:
             self.commandAfterStop = self.Quit
@@ -1301,6 +1294,12 @@ class AlgorithmDebugger(bdb.Bdb):
         bdb.Bdb.__init__(self)
         self.doTrace = 0
         self.lastLine = -1
+        self.init_edge_infos = [None, None]
+        self.edge_infos = [None, None]
+        self.init_vertex_infos = [None, None]
+        self.vertex_infos = [None, None]
+        self.init_graph_infos = [None, None]
+        self.graph_infos = [None, None]
         
     def dispatch_line(self, frame):
         """ *Internal* Only dispatch if we are in the algorithm file """
@@ -1437,16 +1436,112 @@ class AlgorithmDebugger(bdb.Bdb):
         else: exc_type_name = exc_type.__name__
         #log.debug("exc_type_name: %s" repr.repr(exc_value))
         self.interaction(frame, exc_traceback)
+      
+    def add_info_commands_to_history(self):
+        ''' Inspects the graphInformer of each graph display to look for changes to 
+            the edge, graph, and vertex info.  If there are changes then we execute 
+            the relevant command in GraphDisplay so it shows up in the animation history
+        '''
+        # TODO: These functions can definitely be consolidated...
+        def construct_initial_graph_infos():
+            for i in xrange(num_graphs):
+                if self.init_graph_infos[i] is None:
+                    self.init_graph_infos[i] = informers[i].DefaultInfo()
+                    self.graph_infos[i] = copy.deepcopy(self.init_graph_infos[i])
+
+        def construct_initial_edge_infos():
+            for i in xrange(num_graphs):
+                if self.init_edge_infos[i] is None:
+                    self.init_edge_infos[i] = {}
+                    for e in edges[i]:
+                        self.init_edge_infos[i][e] = informers[i].EdgeInfo(e[0], e[1])
+                    self.edge_infos[i] = copy.deepcopy(self.init_edge_infos[i])
+
+        def construct_initial_vertex_infos():
+            for i in xrange(num_graphs):
+                if self.init_vertex_infos[i] is None:
+                    self.init_vertex_infos[i] = {}
+                    for v in vertices[i]:
+                        self.init_vertex_infos[i][v] = informers[i].VertexInfo(v)
+                    self.vertex_infos[i] = copy.deepcopy(self.init_vertex_infos[i])
+
+        def check_for_edge_info_changes():
+            for i in xrange(num_graphs):
+                edge_infos = self.edge_infos[i]
+                history = histories[i]
+                informer = informers[i]
+                for e in edges[i]:
+                    if e not in edge_infos:
+                        edge_infos[e] = informer.EdgeInfo(e[0], e[1])
+                        history.UpdateEdgeInfo(e[0], e[1], edge_infos[e])
+                    else:
+                        past_info = edge_infos[e]
+                        curr_info = informer.EdgeInfo(e[0], e[1])
+                        if past_info != curr_info:
+                            edge_infos[e] = curr_info
+                            history.UpdateEdgeInfo(e[0], e[1], curr_info)
+                
+                for e in edge_infos.keys():
+                    if e not in edges[i]:
+                        del edge_infos[e]
+
+        def check_for_vertex_info_changes():
+            for i in xrange(num_graphs):
+                vertex_infos = self.vertex_infos[i]
+                history = histories[i]
+                informer = informers[i]
+                for v in vertices[i]:
+                    if v not in vertex_infos:
+                        vertex_infos[v] = informer.VertexInfo(v)
+                        history.UpdateVertexInfo(v, vertex_infos[v])
+                    else:
+                        past_info = vertex_infos[v]
+                        curr_info = informer.VertexInfo(v)
+                        if past_info != curr_info:
+                            vertex_infos[v] = curr_info
+                            history.UpdateVertexInfo(v, curr_info)
+
+                for v in vertex_infos.keys():
+                    if v not in vertices[i]:
+                        del vertex_infos[v]
+
+        def check_for_graph_info_changes():
+            for i in xrange(num_graphs):
+                if self.graph_infos[i] != informers[i].DefaultInfo():
+                    self.graph_infos[i] = informers[i].DefaultInfo()
+                    histories[i].UpdateGraphInfo(self.graph_infos[i])
+
+        # Note since naming is weird: self.GUI is the Algorithm() instance.  self.GUI.GUI is the AlgoWin instance
+        num_graphs = 1
+        informers = [self.GUI.GUI.graphDisplay.graphInformer]
+        vertices = [self.GUI.graph.vertices]
+        edges = [self.GUI.graph.edgeWeights[0].keys()]    # list of tuples that are edges
+        histories = [self.GUI.animation_history]
+        if self.GUI.GUI.secondaryGraphDisplay is not None and self.GUI.GUI.secondaryGraphDisplay.graphInformer is not None:
+            num_graphs = 2
+            histories.append(self.GUI.GUI.secondaryGraphDisplay)
+            informers.append(self.GUI.GUI.secondaryGraphDisplay.graphInformer)
+            edges.append(self.GUI.GUI.secondaryGraphDisplay.drawEdges.keys())
+            vertices.append(self.GUI.GUI.secondaryGraphDisplay.drawVertex.keys())
+
+        construct_initial_graph_infos()
+        construct_initial_edge_infos()
+        construct_initial_vertex_infos()
+        check_for_graph_info_changes()
+        check_for_edge_info_changes()
+        check_for_vertex_info_changes()
         
-        
+
     def interaction(self, frame, traceback):
         """ *Internal* This function does all the interaction with the user
             depending on self.GUI.mode
         
             - Step (self.GUI.mode == 2)
             - Quit (self.GUI.mode == 0)
-            - Auto-run w/timer (self.GUI.mode == 1)"""
-        
+            - Auto-run w/timer (self.GUI.mode == 1)
+        """
+        self.add_info_commands_to_history()
+
         self.setup(frame, traceback)
         # 
         #line = self.currentLine(frame)
@@ -1501,7 +1596,8 @@ class Algorithm:
         self.algoGlobals = {}       # Sandbox for Algorithm
         self.logAnimator = 1
         self.about = None
-        
+        self.animation_history = None
+
         self.commentPattern = re.compile('[ \t]*#')
         self.blankLinePattern = re.compile('[ \t]*\n')
         
@@ -1612,7 +1708,7 @@ class Algorithm:
         """ Read in a graph from file and open the display """
         if type(file) in types.StringTypes:
             self.graphFileName = file
-        elif type(file)==types.FileType or issubclass(file.__class__,StringIO.StringIO):
+        elif type(file) == types.FileType or issubclass(file.__class__,StringIO.StringIO):
             self.graphFileName = fileName
         else:
             raise Exception("wrong types in argument list: expected string or file like object")
@@ -1623,18 +1719,20 @@ class Algorithm:
         self.GUI.graphDisplay.RegisterGraphInformer(WeightedGraphInformer(self.graph))
         self.GUI.graphDisplay.UpdateScrollRegion(auto=1)
         
+        if self.graphDisplays == 2:
+            # Open a secondary empty graph to overwrite the results of last algorithm run
+            self.OpenSecondaryGraph(Graph.Graph(), 'tmp')
+
     def restoreGraph(self):
         self.graph=copy.deepcopy(self.cleanGraphCopy)
         self.graphIsDirty = 0
         
-    def OpenSecondaryGraph(self,G,title,informer=None):
+    def OpenSecondaryGraph(self, G, title, informer=None):
         """ Read in graph from file and open the the second display """
         self.GUI.OpenSecondaryGraphDisplay()
         self.GUI.secondaryGraphDisplay.ShowGraph(G, title)
         self.GUI.secondaryGraphDisplay.UpdateScrollRegion(auto=1)
-        if informer is not None:
-            self.GUI.secondaryGraphDisplay.RegisterGraphInformer(informer)
-            
+        self.GUI.secondaryGraphDisplay.RegisterGraphInformer(informer)
             
     def ReadyToStart(self):
         """ Return 1 if we are ready to run. That is when we user
@@ -1860,7 +1958,7 @@ class Algorithm:
         
             Proper names for properties are defined in gProperty
         """
-        for property,requiredValue in propertyValueDict.iteritems():
+        for property, requiredValue in propertyValueDict.iteritems():
             failed = 0
             value = self.graph.Property(property)
             if value != 'Unknown':   
@@ -1877,7 +1975,7 @@ class Algorithm:
             
             if failed or value == 'Unknown':
                 # For GatoTest: Abort if needed property is missing from graph 
-                if not g.Interactive:
+                if not g.Interactive and not g.GeneratingSVG:
                     raise AbortProlog, "Not running interactively. Aborting due to" \
                           " check for property %s" % property                    
                 errMsg = "The algorithm %s requires that the graph %s has %s" % \
@@ -1890,6 +1988,12 @@ class Algorithm:
                     errMsg += " of %s or more" % str(requiredValue)
                 if value == "Unknown":
                     errMsg += ". This is not known"
+
+                if g.GeneratingSVG:
+                    # If we are generating SVG animations with GatoTest.py we want to proceed even if NeededProperties aren't met
+                    print "Warning: " + errMsg
+                    return
+
                 errMsg += ".\nDo you still want to proceed ?"                          
                 r = askokcancel("Gato - Error", errMsg)
                 if r == False:
@@ -2003,6 +2107,8 @@ def main(argv=None):
             pw.pack(fill=BOTH, expand=1)
             graph_panes = PanedWindow(pw, orient=VERTICAL)
             app = AlgoWin(tk, graph_panes, experimental=experimental)
+            if debug:
+                app.algorithm.logAnimator = 2
             app.OpenSecondaryGraphDisplay()
             graph_panes.add(app.graphDisplay)
             graph_panes.add(app.secondaryGraphDisplay)                        
@@ -2019,8 +2125,8 @@ def main(argv=None):
             app.OneGraphWindow()
         else:
             app = AlgoWin(tk,experimental=experimental)
-        if debug:
-            app.algorithm.logAnimator = 2
+            if debug:
+                app.algorithm.logAnimator = 2
 
         # On MacOS X the Quit menu entry otherwise bypasses our Quit
         # Handler According to
