@@ -5,7 +5,7 @@
 #	file:   GatoGlobals.py
 #	author: Alexander Schliep (alexander@schliep.org)
 #
-#       Copyright (C) 1998-2011, Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
 #       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
 #       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de             
@@ -28,8 +28,8 @@
 #
 #
 #
-#       This file is version $Revision: 444 $ 
-#                       from $Date: 2011-08-25 10:41:55 -0400 (Thu, 25 Aug 2011) $
+#       This file is version $Revision: 670 $ 
+#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
 #             last change by $Author: schliep $.
 #
 #
@@ -37,8 +37,8 @@
 
 import tkFont
 
-gatoVersion = '1.1.2'
-gatoBuildDate = '8/25/2011'
+gatoVersion = '1.2.2'
+gatoBuildDate = '1/13/2015'
 
 class AnimationParameters:
     """ Convenience class to collect all globals. 
@@ -61,6 +61,9 @@ class AnimationParameters:
     BlinkRepeat = 3 # One more than you want
     Interactive = 1
 
+    # Other
+    GeneratingSVG = 0
+
     # Printing
     PaperHeight = 1500 # "20i" XXX Should be real paper size
     PaperWidth = 1500 # "20i"
@@ -157,7 +160,9 @@ gProperty = {
     'EvenOrder':(0, 'an even number of vertices', 'even order'),
     # Whether the first set of edge weights G.edgeWeights[0] are all non-negative
     'NonNegativeEdgeWeights':(0, 'edge weights which are all non-negative',
-                              'non-negative edge weights')
+                              'non-negative edge weights'),
+    # Number of edges on graph
+    'Size': (0, 'no edges', 'number of edges')
     }
 
 
