@@ -5,7 +5,7 @@
 #	file:   Graph.py
 #	author: Alexander Schliep (alexander@schliep.org)
 #
-#       Copyright (C) 1998-2011, Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
 #       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
 #       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de             
@@ -28,8 +28,8 @@
 #
 #
 #
-#       This file is version $Revision: 435 $ 
-#                       from $Date: 2011-05-05 12:36:29 -0400 (Thu, 05 May 2011) $
+#       This file is version $Revision: 670 $ 
+#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -85,7 +85,7 @@ class Graph:
         self.edgeWeights      = {}   # Dictionary of edge labellings
         self.edgeWeights[0]   = EdgeWeight(self)
         self.vertexWeights    = {}   # None by default
-        self.size             = 0
+        self.size             = 0    # Number of edges
         self.edgeWidth        = None
         self.vertexAnnotation = None
         self.edgeAnnotation   = None
@@ -443,7 +443,9 @@ class Graph:
             #if self.euclidian:
             #    return True
             #else:
-            return self.QNonNegativeEdgeWeights()     
+            return self.QNonNegativeEdgeWeights() 
+        elif name == 'Size':
+            return self.size
         else:
             try:
                 return self.properties[name]
