@@ -5,7 +5,7 @@
 #	file:   GraphDisplay.py
 #	author: Alexander Schliep (alexander@schliep.org)
 #
-#       Copyright (C) 1998-2011, Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
 #       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
 #       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de
@@ -28,8 +28,8 @@
 #
 #
 #
-#       This file is version $Revision: 442 $ 
-#                       from $Date: 2011-07-19 17:05:31 -0400 (Tue, 19 Jul 2011) $
+#       This file is version $Revision: 670 $ 
+#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -42,6 +42,7 @@ import GatoGlobals
 from GatoUtil import orthogonal
 from GatoDialogs import AutoScrollbar
 from DataStructures import Point2D, VertexLabeling, EdgeLabeling
+from AnimatedDataStructures import ComponentMaker
 import os
 import colorsys
 
@@ -50,6 +51,10 @@ log = logging.getLogger("GraphDisplay.py")
 
 g = GatoGlobals.AnimationParameters
 
+
+
+
+
 class ZoomVar(StringVar):
     """ *Internal* helper class to have TK update variable correspoding
         to pop-up state """
@@ -669,8 +674,20 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
             self.canvas.itemconfig( self.drawLabel[v], fill=g.cLabelDefault)
         self.canvas.itemconfig( self.drawVertex[v], fill=color)
         self.update()
-        
-        
+
+
+    # Empty function used to get updates in AnimationHistory
+    def UpdateEdgeInfo(self, tail, head, info):
+        pass
+
+    # Empty function used to get updates in AnimationHistory
+    def UpdateGraphInfo(self, info):
+        pass
+
+    # Empty function used to get updates in AnimationHistory
+    def UpdateVertexInfo(self, v, info):
+        pass
+
     def GetVertexColor(self,v):
         """ Return the color of v """
         dv = self.drawVertex[v]
@@ -687,7 +704,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
             vertices = graph.vertices
         if vertices is not None: # all specified vertices
             for v in vertices:
-                self.canvas.itemconfig(self.drawVertex[v], fill=color)            
+                self.canvas.itemconfig(self.drawVertex[v], fill=color)           
         self.update()        
         
         
@@ -738,6 +755,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
     def SetEdgesColor(self, edges, color):
         """ Change color of [(tail1,head1),...] to color. No error checking! 
             Handles undirected graphs. """
+        #print "in setEdgesColor in GraphDisplay"
         for tail, head in edges:
             if self.G.QDirected() == 1:
                 de = self.drawEdges[(tail,head)]
@@ -1033,7 +1051,26 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
                 return e
             except:
                 return None
-                
+
+    def CreateBubble(self, vertex_nums, offset_value, color):
+        pass
+
+    def ResizeBubble(self, vertex_nums, new_radius):
+        pass
+
+    def DeleteBubble(self, vertex_nums):
+        pass
+
+    def CreateMoat(self, moat_id, radius, color):
+        # Moat ID is of form 'moat_{vertex_num}-{moat_num}'
+        pass
+
+    def GrowMoat(self, moat_id, radius):
+        pass
+
+    def Wait(self):
+        pass
+
     # XXX: Needs reorganisation. We could highlight paths, circuits
     # and vertex sets. Pretty (but not obvious) would be a convex
     # hull around a vertex set.
@@ -1083,7 +1120,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
             coords += (t.x * self.zoomFactor / 100.0,
                        t.y * self.zoomFactor / 100.0)
         c = self.canvas.create_line(coords, tag="highlight", fill=color,
-                                    width = 16)
+                                    width=16)
         
         self.canvas.lower(c,"edges")
         self.highlightedPath[pathID] = c 
@@ -1092,13 +1129,12 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
     def HidePath(self, pathID):
         #XXX Do we want to hide or delete?
         self.canvas.delete(self.highlightedPath[pathID])
-        
 
     ############################################################################
     #				       
     # edit commands
     #
-    def AddVertex(self, x, y, v = None):
+    def AddVertex(self, x, y, v=None):
         """ *Internal* Add a new vertex at (x,y) 
             NOTE: Assumes x,y to be in embedding coordinates
         
@@ -1209,14 +1245,15 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
         del(self.drawVertex.label[v])
         self.canvas.delete(self.drawLabel[v])
         del(self.drawLabel.label[v])
-        # delete incident edges
+        """ delete incident edges
         outVertices = self.G.OutNeighbors(v)[:] # Need a copy here
         inVertices = self.G.InNeighbors(v)[:]
-        for w in outVertices:
-            self.DeleteEdge(v,w,0)
-        for w in inVertices:
-            if w != v: # We have already deleted loops
-                self.DeleteEdge(w,v,0)
+        #for w in outVertices:
+        #    self.DeleteEdge(v,w,0)
+        #for w in inVertices:
+        #    if w != v: # We have already deleted loops
+               self.DeleteEdge(w,v,0)
+        """
         self.G.DeleteVertex(v)
 
         
@@ -1321,7 +1358,7 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
         
         printablePageHeight=280 #m
         printablePageWidth =190 #m
-        
+		
         printableRatio=printablePageHeight/printablePageWidth
         
         bbRatio = height/width
@@ -1690,10 +1727,11 @@ class GraphDisplay(): #object): XXX New Style classes fuck up Tkinter
 class GraphDisplayFrame(GraphDisplay, Frame):
     """ Provides graph display in a frame """
     
-    def __init__(self, master=None):
+    def __init__(self, master=None, number=1):
         Frame.__init__(self, master)
         self.pack() 
         self.pack(expand=1,fill=BOTH) # Makes whole window resizeable
+        self.num = number
         GraphDisplay.__init__(self)
         
     def SetTitle(self,title):
