@@ -29,9 +29,9 @@
 #
 #
 #
-#       This file is version $Revision: 310 $
-#                       from $Date: 2007-06-13 10:02:46 -0400 (Wed, 13 Jun 2007) $
-#             last change by $Author: grunau $.
+#       This file is version $Revision: 667 $
+#                       from $Date: 2014-10-08 13:53:59 -0400 (Wed, 08 Oct 2014) $
+#             last change by $Author: schliep $.
 #
 ################################################################################
 import string
@@ -966,7 +966,7 @@ class plot_canvas(Tkinter.Canvas):
                                  self.scale_offset_y+2)
             text=self.create_text(pixel_x,self.scale_offset_y+2,
                                   anchor=Tkinter.N,
-                                  text=str(round(pos_x,prec)))
+                                  text=str(round(pos_x,int(prec))))
             self.tic_list.append(tic)
             self.tic_list.append(text)
             pos_x+=dist
