@@ -6,7 +6,7 @@
 #	file:   ProbEditorWidgets.py
 #	author: Achim Gaedke (achim.gaedke@zpr.uni-koeln.de)
 #
-#       Copyright (C) 1998-2011, Alexander Schliep, Winfried Hochstaettler and 
+#       Copyright (C) 1998-2015, Alexander Schliep, Winfried Hochstaettler and 
 #       Copyright 1998-2001 ZAIK/ZPR, Universitaet zu Koeln
 #                                   
 #       Contact: alexander@schliep.org, winfried.hochstaettler@fernuni-hagen.de             
@@ -29,8 +29,8 @@
 #
 #
 #
-#       This file is version $Revision: 408 $ 
-#                       from $Date: 2011-03-18 10:28:33 -0400 (Fri, 18 Mar 2011) $
+#       This file is version $Revision: 670 $ 
+#                       from $Date: 2015-01-13 16:04:11 -0500 (Tue, 13 Jan 2015) $
 #             last change by $Author: schliep $.
 #
 ################################################################################
@@ -766,7 +766,7 @@ class scale(Tkinter.Canvas):
         if scale_frac*factor<50:
             scale_frac*=2
             # XXX: the scaling needs some fine tuning
-        round_pos=-math.floor(math.log10(scale_frac))
+        round_pos=int(-math.floor(math.log10(scale_frac)))
         x_pos=0.0
         while x_pos<=max_value:
             pixel_x=start_x+x_pos*factor
@@ -942,7 +942,7 @@ class pie_chart(Tkinter.Canvas,flyout_decoration):
             key='other'
         value=abs(float(self.itemcget(sector,'extent')))/360.0*self.ProbDict.sum
         l10_value=-math.floor(math.log10(value))
-        info='%s: %s'%(key,str(round(value,l10_value+3)))
+        info='%s: %s'%(key,str(round(value,int(l10_value+3))))
         return info
         
     def anchor(self,angle,angle_base):
